@@ -1,6 +1,10 @@
 from django_prometheus.db import (
-    connections_total, execute_total, execute_many_total, errors_total,
-    connection_errors_total)
+    connection_errors_total,
+    connections_total,
+    errors_total,
+    execute_many_total,
+    execute_total,
+)
 
 
 class ExceptionCounterByType(object):
@@ -17,7 +21,7 @@ class ExceptionCounterByType(object):
         handle_get_request()
     """
 
-    def __init__(self, counter, type_label='type', extra_labels=None):
+    def __init__(self, counter, type_label="type", extra_labels=None):
         self._counter = counter
         self._type_label = type_label
         self._labels = extra_labels
@@ -37,15 +41,15 @@ class DatabaseWrapperMixin(object):
     def get_new_connection(self, *args, **kwargs):
         connections_total.labels(self.alias, self.vendor).inc()
         try:
-            return super(DatabaseWrapperMixin, self).get_new_connection(
-                *args, **kwargs)
-        except:
+            return super(DatabaseWrapperMixin, self).get_new_connection(*args, **kwargs)
+        except Exception:
             connection_errors_total.labels(self.alias, self.vendor).inc()
             raise
 
     def create_cursor(self, name=None):
-        return self.connection.cursor(factory=ExportingCursorWrapper(
-            self.CURSOR_CLASS, self.alias, self.vendor))
+        return self.connection.cursor(
+            factory=ExportingCursorWrapper(self.CURSOR_CLASS, self.alias, self.vendor)
+        )
 
 
 def ExportingCursorWrapper(cursor_class, alias, vendor):
@@ -58,15 +62,19 @@ def ExportingCursorWrapper(cursor_class, alias, vendor):
 
         def execute(self, *args, **kwargs):
             execute_total.labels(alias, vendor).inc()
-            with ExceptionCounterByType(errors_total, extra_labels={
-                    'alias': alias, 'vendor': vendor}):
+            with ExceptionCounterByType(
+                errors_total, extra_labels={"alias": alias, "vendor": vendor}
+            ):
                 return super(CursorWrapper, self).execute(*args, **kwargs)
 
         def executemany(self, query, param_list, *args, **kwargs):
             execute_total.labels(alias, vendor).inc(len(param_list))
             execute_many_total.labels(alias, vendor).inc(len(param_list))
-            with ExceptionCounterByType(errors_total, extra_labels={
-                    'alias': alias, 'vendor': vendor}):
+            with ExceptionCounterByType(
+                errors_total, extra_labels={"alias": alias, "vendor": vendor}
+            ):
                 return super(CursorWrapper, self).executemany(
-                    query, param_list, *args, **kwargs)
+                    query, param_list, *args, **kwargs
+                )
+
     return CursorWrapper
